package
Version:
v0.0.0-...-8488f5b
Opens a new window with list of versions in this module.
Published: Jul 17, 2016
License: BSD-3-Clause
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type PullInfo struct {
Repo string `json:"repo"`
Type Type `json:"type"`
ID string `json:"id"`
Status Status `json:"status"`
}
const (
StatusExists Status = "exists"
StatusDownloaded Status = "downloaded"
)
const (
TypeImage Type = "image"
TypeLayer Type = "layer"
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.