Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Certificate ¶
type Certificate struct {
// ID is the unique ID of this Certificate
ID string `json:"id,omitempty"`
// Routes contains the IDs of routes assigned to this cert
Routes []string `json:"routes,omitempty"`
// TLSCert is the optional TLS public certificate. It is only used for HTTP routes.
Cert string `json:"cert,omitempty"`
// TLSCert is the optional TLS private key. It is only used for HTTP routes.
Key string `json:"key,omitempty"`
// CreatedAt is the time this cert was created.
CreatedAt time.Time `json:"created_at,omitempty"`
// UpdatedAt is the time this cert was last updated.
UpdatedAt time.Time `json:"updated_at,omitempty"`
}
Certificate describes a TLS certificate for one or more routes
type HTTPRoute ¶
type HTTPRoute struct {
ID string
ParentRef string
Service string
Leader bool
CreatedAt time.Time
UpdatedAt time.Time
Domain string
Certificate *Certificate `json:"certificate,omitempty"`
LegacyTLSCert string `json:"tls_cert,omitempty"`
LegacyTLSKey string `json:"tls_key,omitempty"`
Sticky bool
Path string
}
HTTPRoute is an HTTP Route.
func (HTTPRoute) FormattedID ¶
func (HTTPRoute) MarshalJSON ¶
type Route ¶
type Route struct {
// Type is the type of Route, either "http" or "tcp".
Type string `json:"type"`
// ID is the unique ID of this route.
ID string `json:"id,omitempty"`
// ParentRef is an external opaque identifier used by the route creator for
// filtering and correlation. It typically contains the app ID.
ParentRef string `json:"parent_ref,omitempty"`
// Service is the ID of the service.
Service string `json:"service"`
// Leader is whether or not traffic should only be routed to the leader or
// all instances
Leader bool `json:"leader"`
// CreatedAt is the time this Route was created.
CreatedAt time.Time `json:"created_at,omitempty"`
// UpdatedAt is the time this Route was last updated.
UpdatedAt time.Time `json:"updated_at,omitempty"`
// Domain is the domain name of this Route. It is only used for HTTP routes.
Domain string `json:"domain,omitempty"`
// Certificate contains TLSCert and TLSKey
Certificate *Certificate `json:"certificate,omitempty"`
// Deprecated in favor of Certificate
LegacyTLSCert string `json:"tls_cert,omitempty"`
LegacyTLSKey string `json:"tls_key,omitempty"`
// Sticky is whether or not to use sticky sessions for this route. It is only
// used for HTTP routes.
Sticky bool `json:"sticky,omitempty"`
// Path is the optional prefix to route to this service. It's exclusive with
// the TLS options and can only be set if a "default" route with the same domain
// and no Path already exists in the route table.
Path string `json:"path,omitempty"`
// Port is the TCP port to listen on for TCP Routes.
Port int32 `json:"port,omitempty"`
}
Route is a struct that combines the fields of HTTPRoute and TCPRoute for easy JSON marshaling.
func (Route) FormattedID ¶
type StreamEvent ¶
Click to show internal directories.
Click to hide internal directories.