Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EC2Image ¶
type EC2Image struct {
ID string `json:"id"`
Name string `json:"name"`
Region string `json:"region"`
OwnerID string `json:"owner_id"`
RootDeviceType string `json:"root_device_type"`
RootDeviceName string `json:"root_device_name"`
RootDeviceSnapshotID string `json:"root_device_snapshot_id"`
VirtualizationType string `json:"virtualization_type"`
Hypervisor string `json:"hypervisor"`
}
type EC2Manifest ¶
type EC2Manifest struct {
Name string `json:"name"`
Versions []*EC2Version `json:"versions"`
}
func (*EC2Manifest) Add ¶
func (m *EC2Manifest) Add(version string, image *EC2Image)
Add adds an image to the manifest.
If the version is already in the manifest, the given image either replaces any existing image with the same region, or is appended to the existing list of images for that version.
If the version is not already in the manifest a new version is added containing the image.
The number of versions in the manifest is capped at the value of maxVersions.
type EC2Version ¶
type VagrantManifest ¶
type VagrantManifest struct {
Name string `json:"name"`
Versions []*VagrantVersion `json:"versions"`
}
func (*VagrantManifest) Add ¶
func (m *VagrantManifest) Add(version string, provider *VagrantProvider)
Add adds a provider to the manifest.
If the version is already in the manifest, the given provider either replaces any existing provider with the same name, or is appended to the existing list of providers for that version.
If the version is not already in the manifest a new version is added containing the provider.
The number of versions in the manifest is capped at the value of maxVersions.
type VagrantProvider ¶
type VagrantVersion ¶
type VagrantVersion struct {
Version string `json:"version"`
Providers []*VagrantProvider `json:"providers"`
}